@@ -5,7 +5,7 @@ import os
 import logging
 from .compression import compr
 from .utils import (infer_compression, build_name_function,
-                    update_storage_options)
+                    update_storage_options, stringify_path)
 from .registry import get_filesystem_class
 logger = logging.getLogger('fsspec')
 
@@ -54,7 +54,7 @@ class OpenFile(object):
                            self.encoding, self.errors))
 
     def __repr__(self):
-        return f"<OpenFile '{self.path}'>"
+        return "<OpenFile '{}'>".format(self.path)
 
     def __fspath__(self):
         return self.path
@@ -64,27 +64,20 @@ class OpenFile(object):
 
         f = self.fs.open(self.path, mode=mode)
 
-        fobjects = [f]
+        self.fobjects = [f]
 
         if self.compression is not None:
             compress = compr[self.compression]
             f = compress(f, mode=mode[0])
-            fobjects.append(f)
+            self.fobjects.append(f)
 
         if 'b' not in self.mode:
             # assume, for example, that 'r' is equivalent to 'rt' as in builtin
             f = io.TextIOWrapper(f, encoding=self.encoding,
                                  errors=self.errors, newline=self.newline)
-            fobjects.append(f)
+            self.fobjects.append(f)
 
-        self.fobjects = fobjects
-        try:
-            # opened file should know its original path
-            f.__fspath__ = self.__fspath__
-        except AttributeError:
-            # setting that can fail for some C file-like object
-            pass
-        return f
+        return self.fobjects[-1]
 
     def __exit__(self, *args):
         self.close()
@@ -103,12 +96,15 @@ class OpenFile(object):
     def close(self):
         """Close all encapsulated file objects"""
         for f in reversed(self.fobjects):
+            if 'r' not in self.mode and not f.closed:
+                f.flush()
             f.close()
         self.fobjects = []
 
 
 def open_files(urlpath, mode='rb', compression=None, encoding='utf8',
-               errors=None, name_function=None, num=1, protocol=None, **kwargs):
+               errors=None, name_function=None, num=1, protocol=None,
+               newline=None, **kwargs):
     """ Given a path or paths, return a list of ``OpenFile`` objects.
 
     For writing, a str path must contain the "*" character, which will be filled
@@ -139,6 +135,9 @@ def open_files(urlpath, mode='rb', compression=None, encoding='utf8',
         name+function)
     protocol : str or None
         If given, overrides the protocol found in the URL.
+    newline : bytes or None
+        Used for line terminator in text mode. If None, uses system default;
+        if blank, uses no translation.
     **kwargs : dict
         Extra options that make sense to a particular storage connection, e.g.
         host, port, username, password, etc.
@@ -157,12 +156,12 @@ def open_files(urlpath, mode='rb', compression=None, encoding='utf8',
                                              storage_options=kwargs,
                                              protocol=protocol)
     return [OpenFile(fs, path, mode=mode, compression=compression,
-                     encoding=encoding, errors=errors)
+                     encoding=encoding, errors=errors, newline=newline)
             for path in paths]
 
 
 def open(urlpath, mode='rb', compression=None, encoding='utf8',
-         errors=None, protocol=None, **kwargs):
+         errors=None, protocol=None, newline=None, **kwargs):
     """ Given a path or paths, return one ``OpenFile`` object.
 
     Parameters
@@ -180,6 +179,9 @@ def open(urlpath, mode='rb', compression=None, encoding='utf8',
         Passed to TextIOWrapper in text mode
     protocol : str or None
         If given, overrides the protocol found in the URL.
+    newline : bytes or None
+        Used for line terminator in text mode. If None, uses system default;
+        if blank, uses no translation.
     **kwargs : dict
         Extra options that make sense to a particular storage connection, e.g.
         host, port, username, password, etc.
@@ -196,7 +198,7 @@ def open(urlpath, mode='rb', compression=None, encoding='utf8',
     ``OpenFile`` object.
     """
     return open_files([urlpath], mode, compression, encoding, errors,
-                      protocol, **kwargs)[0]
+                      protocol, newline=newline, **kwargs)[0]
 
 
 def get_compression(urlpath, compression):
@@ -208,11 +210,23 @@ def get_compression(urlpath, compression):
 
 
 def split_protocol(urlpath):
+    """Return protocol, path pair"""
+    urlpath = stringify_path(urlpath)
     if "://" in urlpath:
-        return urlpath.split("://", 1)
+        protocol, path = urlpath.split("://", 1)
+        if len(protocol) > 1:
+            # excludes Windows paths
+            return protocol, path
     return None, urlpath
 
 
+def strip_protocol(urlpath):
+    """Return only path part of full URL, according to appropriate backend"""
+    protocol, _ = split_protocol(urlpath)
+    cls = get_filesystem_class(protocol)
+    return cls._strip_protocol(urlpath)
+
+
 def expand_paths_if_needed(paths, mode, num, fs, name_function):
     """Expand paths if they have a ``*`` in them.
 
@@ -233,6 +247,8 @@ def expand_paths_if_needed(paths, mode, num, fs, name_function):
     if 'w' in mode and sum([1 for p in paths if '*' in p]) > 1:
         raise ValueError("When writing data, only one filename mask can "
                          "be specified.")
+    elif 'w' in mode:
+        num = max(num, len(paths))
     for curr_path in paths:
         if '*' in curr_path:
             if 'w' in mode:
@@ -281,8 +297,12 @@ def get_fs_token_paths(urlpath, mode='rb', num=1, name_function=None,
             raise ValueError("When specifying a list of paths, all paths must "
                              "share the same protocol")
         cls = get_filesystem_class(protocol)
+        optionss = list(map(cls._get_kwargs_from_urls, urlpath))
         paths = [cls._strip_protocol(u) for u in urlpath]
-        options = cls._get_kwargs_from_urls(paths)
+        options = optionss[0]
+        if not all(o == options for o in optionss):
+            raise ValueError("When specifying a list of paths, all paths must "
+                             "share the same file-system options")
         update_storage_options(options, storage_options)
         fs = cls(**options)
         paths = expand_paths_if_needed(paths, mode, num, fs, name_function)
@@ -292,8 +312,8 @@ def get_fs_token_paths(urlpath, mode='rb', num=1, name_function=None,
         protocol = protocol or protocols
         cls = get_filesystem_class(protocol)
 
-        path = cls._strip_protocol(urlpath)
         options = cls._get_kwargs_from_urls(urlpath)
+        path = cls._strip_protocol(urlpath)
         update_storage_options(options, storage_options)
         fs = cls(**options)
 
@@ -307,13 +327,15 @@ def get_fs_token_paths(urlpath, mode='rb', num=1, name_function=None,
     else:
         raise TypeError('url type not understood: %s' % urlpath)
 
-    return fs, fs.token, paths
+    return fs, fs._fs_token, paths
 
 
 def _expand_paths(path, name_function, num):
     if isinstance(path, str):
-        if path.count('*') != 1:
+        if path.count('*') > 1:
             raise ValueError("Output path spec must contain exactly one '*'.")
+        elif "*" not in path:
+            path = os.path.join(path, "*.part")
 
         if name_function is None:
             name_function = build_name_function(num - 1)
@@ -425,6 +447,9 @@ class BytesCache(BaseCache):
     """
 
     def __init__(self, blocksize, fetcher, size, trim=True, **kwargs):
+        if blocksize is None:
+            import pdb
+            pdb.set_trace()
         super().__init__(blocksize, fetcher, size)
         self.cache = b''
         self.start = None
