@@ -78,27 +78,39 @@ class LocalFileSystem(AbstractFileSystem):
         """ Copy within two locations in the filesystem"""
         shutil.copyfile(path1, path2)
 
-    get = copy
-    put = copy
+    def get(self, path1, path2, **kwargs):
+        """ Copy file to local """
+        if kwargs.get("recursive"):
+            return super(LocalFileSystem, self).get(path1, path2, **kwargs)
+        else:
+            return self.copy(path1, path2, **kwargs)
+
+    def put(self, path1, path2, **kwargs):
+        """ Upload file from local """
+        if kwargs.get("recursive"):
+            return super(LocalFileSystem, self).put(path1, path2, **kwargs)
+        else:
+            return self.copy(path1, path2, **kwargs)
 
     def mv(self, path1, path2, **kwargs):
         """ Move file from one location to another """
         os.rename(path1, path2)
 
     def rm(self, path, recursive=False, maxdepth=None):
-        if recursive:
+        if recursive and self.isdir(path):
             shutil.rmtree(path)
         else:
             os.remove(path)
 
     def _open(self, path, mode='rb', block_size=None, **kwargs):
-        path = make_path_posix(path)
+        path = self._strip_protocol(path)
         if self.auto_mkdir:
             self.makedirs(self._parent(path), exist_ok=True)
         return LocalFileOpener(path, mode, fs=self, **kwargs)
 
     def touch(self, path, **kwargs):
         """ Create empty file, or update timestamp """
+        path = self._strip_protocol(path)
         if self.exists(path):
             os.utime(path, None)
         else:
@@ -106,7 +118,7 @@ class LocalFileSystem(AbstractFileSystem):
 
     @classmethod
     def _parent(cls, path):
-        path = make_path_posix(path).rstrip('/')
+        path = cls._strip_protocol(path).rstrip('/')
         if '/' in path:
             return path.rsplit('/', 1)[0]
         else:
@@ -120,16 +132,25 @@ class LocalFileSystem(AbstractFileSystem):
         return make_path_posix(path)
 
 
-def make_path_posix(path):
+def make_path_posix(path, sep=os.sep):
     """ Make path generic """
     if re.match('/[A-Za-z]:', path):
         # for windows file URI like "file:///C:/folder/file"
         # or "file:///C:\\dir\\file"
         path = path[1:]
-    if os.sep not in path and '/' not in path:
-        path = os.path.abspath(path)
     if path.startswith('\\') or re.match("[\\\\]*[A-Za-z]:", path):
+        # windows full path "\\server\\path" or "C:\\local\\path"
         return path.lstrip('\\').replace('\\', '/').replace('//', '/')
+    if (
+            sep not in path and '/' not in path
+            or (sep == '/' and not path.startswith('/'))
+            or (sep == '\\' and ":" not in path)
+            ):
+        # relative path like "path" or "rel\\path" (win) or rel/path"
+        path = os.path.abspath(path)
+        if os.sep == "\\":
+            # abspath made some more '\\' separators
+            return make_path_posix(path, sep)
     return path
 
 
