@@ -17,8 +17,12 @@ known_implementations = {
     'zip': {'class': 'fsspec.implementations.zip.ZipFileSystem'},
     'gcs': {'class': 'gcsfs.GCSFileSystem',
             'err': 'Please install gcsfs to access Google Storage'},
+    'gs': {'class': 'gcsfs.GCSFileSystem',
+           'err': 'Please install gcsfs to access Google Storage'},
     'sftp': {'class': 'fsspec.implementations.sftp.SFTPFileSystem',
              'err': 'SFTPFileSystem requires "paramiko" to be installed'},
+    'ssh': {'class': 'fsspec.implementations.sftp.SFTPFileSystem',
+            'err': 'SFTPFileSystem requires "paramiko" to be installed'},
     'ftp': {'class': 'fsspec.implementations.ftp.FTPFileSystem'},
     'hdfs': {'class': 'fsspec.implementations.hdfs.PyArrowHDFS',
              'err': 'pyarrow and local java libraries required for HDFS'},
@@ -26,7 +30,9 @@ known_implementations = {
                 'err': 'webHDFS access requires "requests" to be installed'},
     's3': {'class': 's3fs.S3FileSystem',
            'err': 'Install s3fs to access S3'},
-    'cached': {'class': 'fsspec.implementations.cached.CachingFileSystem'}
+    'cached': {'class': 'fsspec.implementations.cached.CachingFileSystem'},
+    'dask': {'class': 'fsspec.implementations.dask.DaskWorkerFileSystem',
+             'err': 'Install dask distributed to access worker file system'}
 }
 
 
